# coding: utf-8

"""
    Gate API v4

    Welcome to Gate.io API  APIv4 provides spot, margin and futures trading operations. There are public APIs to retrieve the real-time market statistics, and private APIs which needs authentication to trade on user's behalf.  # noqa: E501

    Contact: support@mail.gate.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from gate_api.api_client import ApiClient
from gate_api.exceptions import ApiTypeError, ApiValueError  # noqa: F401


class WithdrawalApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def withdraw(self, ledger_record, **kwargs):  # noqa: E501
        """Withdraw  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.withdraw(ledger_record, async_req=True)
        >>> result = thread.get()

        :param bool async_req: execute request asynchronously
        :param LedgerRecord ledger_record: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :rtype: gate_api.LedgerRecord
        :return: If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.withdraw_with_http_info(ledger_record, **kwargs)  # noqa: E501

    def withdraw_with_http_info(self, ledger_record, **kwargs):  # noqa: E501
        """Withdraw  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.withdraw_with_http_info(ledger_record, async_req=True)
        >>> result = thread.get()

        :param bool async_req: execute request asynchronously
        :param LedgerRecord ledger_record: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :rtype: tuple(gate_api.LedgerRecord, status_code(int), headers(HTTPHeaderDict))
        :return: If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['ledger_record']
        all_params.extend(['async_req', '_return_http_data_only', '_preload_content', '_request_timeout'])

        for k, v in six.iteritems(local_var_params['kwargs']):
            if k not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method withdraw" % k)
            local_var_params[k] = v
        del local_var_params['kwargs']
        # verify the required parameter 'ledger_record' is set
        if self.api_client.client_side_validation and (
            'ledger_record' not in local_var_params or local_var_params['ledger_record'] is None  # noqa: E501
        ):  # noqa: E501
            raise ApiValueError("Missing the required parameter `ledger_record` when calling `withdraw`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'ledger_record' in local_var_params:
            body_params = local_var_params['ledger_record']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json']
        )  # noqa: E501

        # Authentication setting
        auth_settings = ['apiv4']  # noqa: E501

        return self.api_client.call_api(
            '/withdrawals',
            'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='LedgerRecord',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
        )

    def cancel_withdrawal(self, withdrawal_id, **kwargs):  # noqa: E501
        """Cancel withdrawal with specified ID  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cancel_withdrawal(withdrawal_id, async_req=True)
        >>> result = thread.get()

        :param bool async_req: execute request asynchronously
        :param str withdrawal_id: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :rtype: gate_api.LedgerRecord
        :return: If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.cancel_withdrawal_with_http_info(withdrawal_id, **kwargs)  # noqa: E501

    def cancel_withdrawal_with_http_info(self, withdrawal_id, **kwargs):  # noqa: E501
        """Cancel withdrawal with specified ID  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cancel_withdrawal_with_http_info(withdrawal_id, async_req=True)
        >>> result = thread.get()

        :param bool async_req: execute request asynchronously
        :param str withdrawal_id: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :rtype: tuple(gate_api.LedgerRecord, status_code(int), headers(HTTPHeaderDict))
        :return: If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['withdrawal_id']
        all_params.extend(['async_req', '_return_http_data_only', '_preload_content', '_request_timeout'])

        for k, v in six.iteritems(local_var_params['kwargs']):
            if k not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method cancel_withdrawal" % k)
            local_var_params[k] = v
        del local_var_params['kwargs']
        # verify the required parameter 'withdrawal_id' is set
        if self.api_client.client_side_validation and (
            'withdrawal_id' not in local_var_params or local_var_params['withdrawal_id'] is None  # noqa: E501
        ):  # noqa: E501
            raise ApiValueError(
                "Missing the required parameter `withdrawal_id` when calling `cancel_withdrawal`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'withdrawal_id' in local_var_params:
            path_params['withdrawal_id'] = local_var_params['withdrawal_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apiv4']  # noqa: E501

        return self.api_client.call_api(
            '/withdrawals/{withdrawal_id}',
            'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='LedgerRecord',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
        )



# coding: utf-8

"""
    Gate API v4

    Welcome to Gate.io API  APIv4 provides spot, margin and futures trading operations. There are public APIs to retrieve the real-time market statistics, and private APIs which needs authentication to trade on user's behalf.  # noqa: E501

    Contact: support@mail.gate.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from gate_api.configuration import Configuration


class OptionsPosition(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'user': 'int',
        'contract': 'str',
        'size': 'int',
        'entry_price': 'str',
        'mark_price': 'str',
        'realised_pnl': 'str',
        'unrealised_pnl': 'str',
        'pending_orders': 'int',
        'close_order': 'PositionCloseOrder',
    }

    attribute_map = {
        'user': 'user',
        'contract': 'contract',
        'size': 'size',
        'entry_price': 'entry_price',
        'mark_price': 'mark_price',
        'realised_pnl': 'realised_pnl',
        'unrealised_pnl': 'unrealised_pnl',
        'pending_orders': 'pending_orders',
        'close_order': 'close_order',
    }

    def __init__(
        self,
        user=None,
        contract=None,
        size=None,
        entry_price=None,
        mark_price=None,
        realised_pnl=None,
        unrealised_pnl=None,
        pending_orders=None,
        close_order=None,
        local_vars_configuration=None,
    ):  # noqa: E501
        # type: (int, str, int, str, str, str, str, int, PositionCloseOrder, Configuration) -> None
        """OptionsPosition - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._user = None
        self._contract = None
        self._size = None
        self._entry_price = None
        self._mark_price = None
        self._realised_pnl = None
        self._unrealised_pnl = None
        self._pending_orders = None
        self._close_order = None
        self.discriminator = None

        if user is not None:
            self.user = user
        if contract is not None:
            self.contract = contract
        if size is not None:
            self.size = size
        if entry_price is not None:
            self.entry_price = entry_price
        if mark_price is not None:
            self.mark_price = mark_price
        if realised_pnl is not None:
            self.realised_pnl = realised_pnl
        if unrealised_pnl is not None:
            self.unrealised_pnl = unrealised_pnl
        if pending_orders is not None:
            self.pending_orders = pending_orders
        self.close_order = close_order

    @property
    def user(self):
        """Gets the user of this OptionsPosition.  # noqa: E501

        User ID  # noqa: E501

        :return: The user of this OptionsPosition.  # noqa: E501
        :rtype: int
        """
        return self._user

    @user.setter
    def user(self, user):
        """Sets the user of this OptionsPosition.

        User ID  # noqa: E501

        :param user: The user of this OptionsPosition.  # noqa: E501
        :type: int
        """

        self._user = user

    @property
    def contract(self):
        """Gets the contract of this OptionsPosition.  # noqa: E501

        Futures contract  # noqa: E501

        :return: The contract of this OptionsPosition.  # noqa: E501
        :rtype: str
        """
        return self._contract

    @contract.setter
    def contract(self, contract):
        """Sets the contract of this OptionsPosition.

        Futures contract  # noqa: E501

        :param contract: The contract of this OptionsPosition.  # noqa: E501
        :type: str
        """

        self._contract = contract

    @property
    def size(self):
        """Gets the size of this OptionsPosition.  # noqa: E501

        Position size  # noqa: E501

        :return: The size of this OptionsPosition.  # noqa: E501
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this OptionsPosition.

        Position size  # noqa: E501

        :param size: The size of this OptionsPosition.  # noqa: E501
        :type: int
        """

        self._size = size

    @property
    def entry_price(self):
        """Gets the entry_price of this OptionsPosition.  # noqa: E501

        Entry price  # noqa: E501

        :return: The entry_price of this OptionsPosition.  # noqa: E501
        :rtype: str
        """
        return self._entry_price

    @entry_price.setter
    def entry_price(self, entry_price):
        """Sets the entry_price of this OptionsPosition.

        Entry price  # noqa: E501

        :param entry_price: The entry_price of this OptionsPosition.  # noqa: E501
        :type: str
        """

        self._entry_price = entry_price

    @property
    def mark_price(self):
        """Gets the mark_price of this OptionsPosition.  # noqa: E501

        Current mark price  # noqa: E501

        :return: The mark_price of this OptionsPosition.  # noqa: E501
        :rtype: str
        """
        return self._mark_price

    @mark_price.setter
    def mark_price(self, mark_price):
        """Sets the mark_price of this OptionsPosition.

        Current mark price  # noqa: E501

        :param mark_price: The mark_price of this OptionsPosition.  # noqa: E501
        :type: str
        """

        self._mark_price = mark_price

    @property
    def realised_pnl(self):
        """Gets the realised_pnl of this OptionsPosition.  # noqa: E501

        Realized PNL  # noqa: E501

        :return: The realised_pnl of this OptionsPosition.  # noqa: E501
        :rtype: str
        """
        return self._realised_pnl

    @realised_pnl.setter
    def realised_pnl(self, realised_pnl):
        """Sets the realised_pnl of this OptionsPosition.

        Realized PNL  # noqa: E501

        :param realised_pnl: The realised_pnl of this OptionsPosition.  # noqa: E501
        :type: str
        """

        self._realised_pnl = realised_pnl

    @property
    def unrealised_pnl(self):
        """Gets the unrealised_pnl of this OptionsPosition.  # noqa: E501

        Unrealized PNL  # noqa: E501

        :return: The unrealised_pnl of this OptionsPosition.  # noqa: E501
        :rtype: str
        """
        return self._unrealised_pnl

    @unrealised_pnl.setter
    def unrealised_pnl(self, unrealised_pnl):
        """Sets the unrealised_pnl of this OptionsPosition.

        Unrealized PNL  # noqa: E501

        :param unrealised_pnl: The unrealised_pnl of this OptionsPosition.  # noqa: E501
        :type: str
        """

        self._unrealised_pnl = unrealised_pnl

    @property
    def pending_orders(self):
        """Gets the pending_orders of this OptionsPosition.  # noqa: E501

        Current open orders  # noqa: E501

        :return: The pending_orders of this OptionsPosition.  # noqa: E501
        :rtype: int
        """
        return self._pending_orders

    @pending_orders.setter
    def pending_orders(self, pending_orders):
        """Sets the pending_orders of this OptionsPosition.

        Current open orders  # noqa: E501

        :param pending_orders: The pending_orders of this OptionsPosition.  # noqa: E501
        :type: int
        """

        self._pending_orders = pending_orders

    @property
    def close_order(self):
        """Gets the close_order of this OptionsPosition.  # noqa: E501


        :return: The close_order of this OptionsPosition.  # noqa: E501
        :rtype: PositionCloseOrder
        """
        return self._close_order

    @close_order.setter
    def close_order(self, close_order):
        """Sets the close_order of this OptionsPosition.


        :param close_order: The close_order of this OptionsPosition.  # noqa: E501
        :type: PositionCloseOrder
        """

        self._close_order = close_order

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict()) if hasattr(item[1], "to_dict") else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OptionsPosition):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OptionsPosition):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Gate API v4

    Welcome to Gate.io API  APIv4 provides spot, margin and futures trading operations. There are public APIs to retrieve the real-time market statistics, and private APIs which needs authentication to trade on user's behalf.  # noqa: E501

    Contact: support@mail.gate.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from gate_api.configuration import Configuration


class FuturesInitialOrder(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'contract': 'str',
        'size': 'int',
        'price': 'str',
        'close': 'bool',
        'tif': 'str',
        'text': 'str',
        'reduce_only': 'bool',
        'is_reduce_only': 'bool',
        'is_close': 'bool',
    }

    attribute_map = {
        'contract': 'contract',
        'size': 'size',
        'price': 'price',
        'close': 'close',
        'tif': 'tif',
        'text': 'text',
        'reduce_only': 'reduce_only',
        'is_reduce_only': 'is_reduce_only',
        'is_close': 'is_close',
    }

    def __init__(
        self,
        contract=None,
        size=None,
        price=None,
        close=False,
        tif='gtc',
        text=None,
        reduce_only=False,
        is_reduce_only=None,
        is_close=None,
        local_vars_configuration=None,
    ):  # noqa: E501
        # type: (str, int, str, bool, str, str, bool, bool, bool, Configuration) -> None
        """FuturesInitialOrder - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._contract = None
        self._size = None
        self._price = None
        self._close = None
        self._tif = None
        self._text = None
        self._reduce_only = None
        self._is_reduce_only = None
        self._is_close = None
        self.discriminator = None

        self.contract = contract
        if size is not None:
            self.size = size
        self.price = price
        if close is not None:
            self.close = close
        if tif is not None:
            self.tif = tif
        if text is not None:
            self.text = text
        if reduce_only is not None:
            self.reduce_only = reduce_only
        if is_reduce_only is not None:
            self.is_reduce_only = is_reduce_only
        if is_close is not None:
            self.is_close = is_close

    @property
    def contract(self):
        """Gets the contract of this FuturesInitialOrder.  # noqa: E501

        Futures contract  # noqa: E501

        :return: The contract of this FuturesInitialOrder.  # noqa: E501
        :rtype: str
        """
        return self._contract

    @contract.setter
    def contract(self, contract):
        """Sets the contract of this FuturesInitialOrder.

        Futures contract  # noqa: E501

        :param contract: The contract of this FuturesInitialOrder.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and contract is None:  # noqa: E501
            raise ValueError("Invalid value for `contract`, must not be `None`")  # noqa: E501

        self._contract = contract

    @property
    def size(self):
        """Gets the size of this FuturesInitialOrder.  # noqa: E501

        Order size. Positive size means to buy, while negative one means to sell. Set to 0 to close the position  # noqa: E501

        :return: The size of this FuturesInitialOrder.  # noqa: E501
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this FuturesInitialOrder.

        Order size. Positive size means to buy, while negative one means to sell. Set to 0 to close the position  # noqa: E501

        :param size: The size of this FuturesInitialOrder.  # noqa: E501
        :type: int
        """

        self._size = size

    @property
    def price(self):
        """Gets the price of this FuturesInitialOrder.  # noqa: E501

        Order price. Set to 0 to use market price  # noqa: E501

        :return: The price of this FuturesInitialOrder.  # noqa: E501
        :rtype: str
        """
        return self._price

    @price.setter
    def price(self, price):
        """Sets the price of this FuturesInitialOrder.

        Order price. Set to 0 to use market price  # noqa: E501

        :param price: The price of this FuturesInitialOrder.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and price is None:  # noqa: E501
            raise ValueError("Invalid value for `price`, must not be `None`")  # noqa: E501

        self._price = price

    @property
    def close(self):
        """Gets the close of this FuturesInitialOrder.  # noqa: E501

        Set to true if trying to close the position  # noqa: E501

        :return: The close of this FuturesInitialOrder.  # noqa: E501
        :rtype: bool
        """
        return self._close

    @close.setter
    def close(self, close):
        """Sets the close of this FuturesInitialOrder.

        Set to true if trying to close the position  # noqa: E501

        :param close: The close of this FuturesInitialOrder.  # noqa: E501
        :type: bool
        """

        self._close = close

    @property
    def tif(self):
        """Gets the tif of this FuturesInitialOrder.  # noqa: E501

        Time in force. If using market price, only `ioc` is supported.  - gtc: GoodTillCancelled - ioc: ImmediateOrCancelled  # noqa: E501

        :return: The tif of this FuturesInitialOrder.  # noqa: E501
        :rtype: str
        """
        return self._tif

    @tif.setter
    def tif(self, tif):
        """Sets the tif of this FuturesInitialOrder.

        Time in force. If using market price, only `ioc` is supported.  - gtc: GoodTillCancelled - ioc: ImmediateOrCancelled  # noqa: E501

        :param tif: The tif of this FuturesInitialOrder.  # noqa: E501
        :type: str
        """
        allowed_values = ["gtc", "ioc"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and tif not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `tif` ({0}), must be one of {1}".format(tif, allowed_values)  # noqa: E501
            )

        self._tif = tif

    @property
    def text(self):
        """Gets the text of this FuturesInitialOrder.  # noqa: E501

        How the order is created. Possible values are: web, api and app  # noqa: E501

        :return: The text of this FuturesInitialOrder.  # noqa: E501
        :rtype: str
        """
        return self._text

    @text.setter
    def text(self, text):
        """Sets the text of this FuturesInitialOrder.

        How the order is created. Possible values are: web, api and app  # noqa: E501

        :param text: The text of this FuturesInitialOrder.  # noqa: E501
        :type: str
        """

        self._text = text

    @property
    def reduce_only(self):
        """Gets the reduce_only of this FuturesInitialOrder.  # noqa: E501

        Set to true to create a reduce-only order  # noqa: E501

        :return: The reduce_only of this FuturesInitialOrder.  # noqa: E501
        :rtype: bool
        """
        return self._reduce_only

    @reduce_only.setter
    def reduce_only(self, reduce_only):
        """Sets the reduce_only of this FuturesInitialOrder.

        Set to true to create a reduce-only order  # noqa: E501

        :param reduce_only: The reduce_only of this FuturesInitialOrder.  # noqa: E501
        :type: bool
        """

        self._reduce_only = reduce_only

    @property
    def is_reduce_only(self):
        """Gets the is_reduce_only of this FuturesInitialOrder.  # noqa: E501

        Is the order reduce-only  # noqa: E501

        :return: The is_reduce_only of this FuturesInitialOrder.  # noqa: E501
        :rtype: bool
        """
        return self._is_reduce_only

    @is_reduce_only.setter
    def is_reduce_only(self, is_reduce_only):
        """Sets the is_reduce_only of this FuturesInitialOrder.

        Is the order reduce-only  # noqa: E501

        :param is_reduce_only: The is_reduce_only of this FuturesInitialOrder.  # noqa: E501
        :type: bool
        """

        self._is_reduce_only = is_reduce_only

    @property
    def is_close(self):
        """Gets the is_close of this FuturesInitialOrder.  # noqa: E501

        Is the order to close position  # noqa: E501

        :return: The is_close of this FuturesInitialOrder.  # noqa: E501
        :rtype: bool
        """
        return self._is_close

    @is_close.setter
    def is_close(self, is_close):
        """Sets the is_close of this FuturesInitialOrder.

        Is the order to close position  # noqa: E501

        :param is_close: The is_close of this FuturesInitialOrder.  # noqa: E501
        :type: bool
        """

        self._is_close = is_close

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict()) if hasattr(item[1], "to_dict") else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FuturesInitialOrder):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, FuturesInitialOrder):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Gate API v4

    Welcome to Gate.io API  APIv4 provides spot, margin and futures trading operations. There are public APIs to retrieve the real-time market statistics, and private APIs which needs authentication to trade on user's behalf.  # noqa: E501

    Contact: support@mail.gate.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from gate_api.configuration import Configuration


class CrossMarginCurrency(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'rate': 'str',
        'prec': 'str',
        'discount': 'str',
        'min_borrow_amount': 'str',
        'user_max_borrow_amount': 'str',
        'total_max_borrow_amount': 'str',
        'price': 'str',
    }

    attribute_map = {
        'name': 'name',
        'rate': 'rate',
        'prec': 'prec',
        'discount': 'discount',
        'min_borrow_amount': 'min_borrow_amount',
        'user_max_borrow_amount': 'user_max_borrow_amount',
        'total_max_borrow_amount': 'total_max_borrow_amount',
        'price': 'price',
    }

    def __init__(
        self,
        name=None,
        rate=None,
        prec=None,
        discount=None,
        min_borrow_amount=None,
        user_max_borrow_amount=None,
        total_max_borrow_amount=None,
        price=None,
        local_vars_configuration=None,
    ):  # noqa: E501
        # type: (str, str, str, str, str, str, str, str, Configuration) -> None
        """CrossMarginCurrency - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._rate = None
        self._prec = None
        self._discount = None
        self._min_borrow_amount = None
        self._user_max_borrow_amount = None
        self._total_max_borrow_amount = None
        self._price = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if rate is not None:
            self.rate = rate
        if prec is not None:
            self.prec = prec
        if discount is not None:
            self.discount = discount
        if min_borrow_amount is not None:
            self.min_borrow_amount = min_borrow_amount
        if user_max_borrow_amount is not None:
            self.user_max_borrow_amount = user_max_borrow_amount
        if total_max_borrow_amount is not None:
            self.total_max_borrow_amount = total_max_borrow_amount
        if price is not None:
            self.price = price

    @property
    def name(self):
        """Gets the name of this CrossMarginCurrency.  # noqa: E501

        Currency name  # noqa: E501

        :return: The name of this CrossMarginCurrency.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this CrossMarginCurrency.

        Currency name  # noqa: E501

        :param name: The name of this CrossMarginCurrency.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def rate(self):
        """Gets the rate of this CrossMarginCurrency.  # noqa: E501

        Loan rate  # noqa: E501

        :return: The rate of this CrossMarginCurrency.  # noqa: E501
        :rtype: str
        """
        return self._rate

    @rate.setter
    def rate(self, rate):
        """Sets the rate of this CrossMarginCurrency.

        Loan rate  # noqa: E501

        :param rate: The rate of this CrossMarginCurrency.  # noqa: E501
        :type: str
        """

        self._rate = rate

    @property
    def prec(self):
        """Gets the prec of this CrossMarginCurrency.  # noqa: E501

        Currency precision  # noqa: E501

        :return: The prec of this CrossMarginCurrency.  # noqa: E501
        :rtype: str
        """
        return self._prec

    @prec.setter
    def prec(self, prec):
        """Sets the prec of this CrossMarginCurrency.

        Currency precision  # noqa: E501

        :param prec: The prec of this CrossMarginCurrency.  # noqa: E501
        :type: str
        """

        self._prec = prec

    @property
    def discount(self):
        """Gets the discount of this CrossMarginCurrency.  # noqa: E501

        Currency value discount, which is used in total value calculation  # noqa: E501

        :return: The discount of this CrossMarginCurrency.  # noqa: E501
        :rtype: str
        """
        return self._discount

    @discount.setter
    def discount(self, discount):
        """Sets the discount of this CrossMarginCurrency.

        Currency value discount, which is used in total value calculation  # noqa: E501

        :param discount: The discount of this CrossMarginCurrency.  # noqa: E501
        :type: str
        """

        self._discount = discount

    @property
    def min_borrow_amount(self):
        """Gets the min_borrow_amount of this CrossMarginCurrency.  # noqa: E501

        Minimum currency borrow amount. Unit is currency itself  # noqa: E501

        :return: The min_borrow_amount of this CrossMarginCurrency.  # noqa: E501
        :rtype: str
        """
        return self._min_borrow_amount

    @min_borrow_amount.setter
    def min_borrow_amount(self, min_borrow_amount):
        """Sets the min_borrow_amount of this CrossMarginCurrency.

        Minimum currency borrow amount. Unit is currency itself  # noqa: E501

        :param min_borrow_amount: The min_borrow_amount of this CrossMarginCurrency.  # noqa: E501
        :type: str
        """

        self._min_borrow_amount = min_borrow_amount

    @property
    def user_max_borrow_amount(self):
        """Gets the user_max_borrow_amount of this CrossMarginCurrency.  # noqa: E501

        Maximum borrow value allowed per user, in USDT  # noqa: E501

        :return: The user_max_borrow_amount of this CrossMarginCurrency.  # noqa: E501
        :rtype: str
        """
        return self._user_max_borrow_amount

    @user_max_borrow_amount.setter
    def user_max_borrow_amount(self, user_max_borrow_amount):
        """Sets the user_max_borrow_amount of this CrossMarginCurrency.

        Maximum borrow value allowed per user, in USDT  # noqa: E501

        :param user_max_borrow_amount: The user_max_borrow_amount of this CrossMarginCurrency.  # noqa: E501
        :type: str
        """

        self._user_max_borrow_amount = user_max_borrow_amount

    @property
    def total_max_borrow_amount(self):
        """Gets the total_max_borrow_amount of this CrossMarginCurrency.  # noqa: E501

        Maximum borrow value allowed for this currency, in USDT  # noqa: E501

        :return: The total_max_borrow_amount of this CrossMarginCurrency.  # noqa: E501
        :rtype: str
        """
        return self._total_max_borrow_amount

    @total_max_borrow_amount.setter
    def total_max_borrow_amount(self, total_max_borrow_amount):
        """Sets the total_max_borrow_amount of this CrossMarginCurrency.

        Maximum borrow value allowed for this currency, in USDT  # noqa: E501

        :param total_max_borrow_amount: The total_max_borrow_amount of this CrossMarginCurrency.  # noqa: E501
        :type: str
        """

        self._total_max_borrow_amount = total_max_borrow_amount

    @property
    def price(self):
        """Gets the price of this CrossMarginCurrency.  # noqa: E501

        Price change between this currency and USDT  # noqa: E501

        :return: The price of this CrossMarginCurrency.  # noqa: E501
        :rtype: str
        """
        return self._price

    @price.setter
    def price(self, price):
        """Sets the price of this CrossMarginCurrency.

        Price change between this currency and USDT  # noqa: E501

        :param price: The price of this CrossMarginCurrency.  # noqa: E501
        :type: str
        """

        self._price = price

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict()) if hasattr(item[1], "to_dict") else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CrossMarginCurrency):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CrossMarginCurrency):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Gate API v4

    Welcome to Gate.io API  APIv4 provides spot, margin and futures trading operations. There are public APIs to retrieve the real-time market statistics, and private APIs which needs authentication to trade on user's behalf.  # noqa: E501

    Contact: support@mail.gate.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from gate_api.configuration import Configuration


class OptionsAccount(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'user': 'int',
        'total': 'str',
        'short_enabled': 'bool',
        'unrealised_pnl': 'str',
        'init_margin': 'str',
        'maint_margin': 'str',
        'order_margin': 'str',
        'available': 'str',
        'point': 'str',
        'currency': 'str',
    }

    attribute_map = {
        'user': 'user',
        'total': 'total',
        'short_enabled': 'short_enabled',
        'unrealised_pnl': 'unrealised_pnl',
        'init_margin': 'init_margin',
        'maint_margin': 'maint_margin',
        'order_margin': 'order_margin',
        'available': 'available',
        'point': 'point',
        'currency': 'currency',
    }

    def __init__(
        self,
        user=None,
        total=None,
        short_enabled=None,
        unrealised_pnl=None,
        init_margin=None,
        maint_margin=None,
        order_margin=None,
        available=None,
        point=None,
        currency=None,
        local_vars_configuration=None,
    ):  # noqa: E501
        # type: (int, str, bool, str, str, str, str, str, str, str, Configuration) -> None
        """OptionsAccount - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._user = None
        self._total = None
        self._short_enabled = None
        self._unrealised_pnl = None
        self._init_margin = None
        self._maint_margin = None
        self._order_margin = None
        self._available = None
        self._point = None
        self._currency = None
        self.discriminator = None

        if user is not None:
            self.user = user
        if total is not None:
            self.total = total
        if short_enabled is not None:
            self.short_enabled = short_enabled
        if unrealised_pnl is not None:
            self.unrealised_pnl = unrealised_pnl
        if init_margin is not None:
            self.init_margin = init_margin
        if maint_margin is not None:
            self.maint_margin = maint_margin
        if order_margin is not None:
            self.order_margin = order_margin
        if available is not None:
            self.available = available
        if point is not None:
            self.point = point
        if currency is not None:
            self.currency = currency

    @property
    def user(self):
        """Gets the user of this OptionsAccount.  # noqa: E501

        User ID  # noqa: E501

        :return: The user of this OptionsAccount.  # noqa: E501
        :rtype: int
        """
        return self._user

    @user.setter
    def user(self, user):
        """Sets the user of this OptionsAccount.

        User ID  # noqa: E501

        :param user: The user of this OptionsAccount.  # noqa: E501
        :type: int
        """

        self._user = user

    @property
    def total(self):
        """Gets the total of this OptionsAccount.  # noqa: E501

        Total account balance  # noqa: E501

        :return: The total of this OptionsAccount.  # noqa: E501
        :rtype: str
        """
        return self._total

    @total.setter
    def total(self, total):
        """Sets the total of this OptionsAccount.

        Total account balance  # noqa: E501

        :param total: The total of this OptionsAccount.  # noqa: E501
        :type: str
        """

        self._total = total

    @property
    def short_enabled(self):
        """Gets the short_enabled of this OptionsAccount.  # noqa: E501

        If the account is allowed to short  # noqa: E501

        :return: The short_enabled of this OptionsAccount.  # noqa: E501
        :rtype: bool
        """
        return self._short_enabled

    @short_enabled.setter
    def short_enabled(self, short_enabled):
        """Sets the short_enabled of this OptionsAccount.

        If the account is allowed to short  # noqa: E501

        :param short_enabled: The short_enabled of this OptionsAccount.  # noqa: E501
        :type: bool
        """

        self._short_enabled = short_enabled

    @property
    def unrealised_pnl(self):
        """Gets the unrealised_pnl of this OptionsAccount.  # noqa: E501

        Unrealized PNL  # noqa: E501

        :return: The unrealised_pnl of this OptionsAccount.  # noqa: E501
        :rtype: str
        """
        return self._unrealised_pnl

    @unrealised_pnl.setter
    def unrealised_pnl(self, unrealised_pnl):
        """Sets the unrealised_pnl of this OptionsAccount.

        Unrealized PNL  # noqa: E501

        :param unrealised_pnl: The unrealised_pnl of this OptionsAccount.  # noqa: E501
        :type: str
        """

        self._unrealised_pnl = unrealised_pnl

    @property
    def init_margin(self):
        """Gets the init_margin of this OptionsAccount.  # noqa: E501

        Initial position margin  # noqa: E501

        :return: The init_margin of this OptionsAccount.  # noqa: E501
        :rtype: str
        """
        return self._init_margin

    @init_margin.setter
    def init_margin(self, init_margin):
        """Sets the init_margin of this OptionsAccount.

        Initial position margin  # noqa: E501

        :param init_margin: The init_margin of this OptionsAccount.  # noqa: E501
        :type: str
        """

        self._init_margin = init_margin

    @property
    def maint_margin(self):
        """Gets the maint_margin of this OptionsAccount.  # noqa: E501

        Position maintenance margin  # noqa: E501

        :return: The maint_margin of this OptionsAccount.  # noqa: E501
        :rtype: str
        """
        return self._maint_margin

    @maint_margin.setter
    def maint_margin(self, maint_margin):
        """Sets the maint_margin of this OptionsAccount.

        Position maintenance margin  # noqa: E501

        :param maint_margin: The maint_margin of this OptionsAccount.  # noqa: E501
        :type: str
        """

        self._maint_margin = maint_margin

    @property
    def order_margin(self):
        """Gets the order_margin of this OptionsAccount.  # noqa: E501

        Order margin of unfinished orders  # noqa: E501

        :return: The order_margin of this OptionsAccount.  # noqa: E501
        :rtype: str
        """
        return self._order_margin

    @order_margin.setter
    def order_margin(self, order_margin):
        """Sets the order_margin of this OptionsAccount.

        Order margin of unfinished orders  # noqa: E501

        :param order_margin: The order_margin of this OptionsAccount.  # noqa: E501
        :type: str
        """

        self._order_margin = order_margin

    @property
    def available(self):
        """Gets the available of this OptionsAccount.  # noqa: E501

        Available balance to transfer out or trade  # noqa: E501

        :return: The available of this OptionsAccount.  # noqa: E501
        :rtype: str
        """
        return self._available

    @available.setter
    def available(self, available):
        """Sets the available of this OptionsAccount.

        Available balance to transfer out or trade  # noqa: E501

        :param available: The available of this OptionsAccount.  # noqa: E501
        :type: str
        """

        self._available = available

    @property
    def point(self):
        """Gets the point of this OptionsAccount.  # noqa: E501

        POINT amount  # noqa: E501

        :return: The point of this OptionsAccount.  # noqa: E501
        :rtype: str
        """
        return self._point

    @point.setter
    def point(self, point):
        """Sets the point of this OptionsAccount.

        POINT amount  # noqa: E501

        :param point: The point of this OptionsAccount.  # noqa: E501
        :type: str
        """

        self._point = point

    @property
    def currency(self):
        """Gets the currency of this OptionsAccount.  # noqa: E501

        Settle currency  # noqa: E501

        :return: The currency of this OptionsAccount.  # noqa: E501
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this OptionsAccount.

        Settle currency  # noqa: E501

        :param currency: The currency of this OptionsAccount.  # noqa: E501
        :type: str
        """

        self._currency = currency

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict()) if hasattr(item[1], "to_dict") else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OptionsAccount):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OptionsAccount):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Gate API v4

    Welcome to Gate.io API  APIv4 provides spot, margin and futures trading operations. There are public APIs to retrieve the real-time market statistics, and private APIs which needs authentication to trade on user's behalf.  # noqa: E501

    Contact: support@mail.gate.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from gate_api.configuration import Configuration


class SpotPricePutOrder(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'type': 'str',
        'side': 'str',
        'price': 'str',
        'amount': 'str',
        'account': 'str',
        'time_in_force': 'str',
    }

    attribute_map = {
        'type': 'type',
        'side': 'side',
        'price': 'price',
        'amount': 'amount',
        'account': 'account',
        'time_in_force': 'time_in_force',
    }

    def __init__(
        self,
        type='limit',
        side=None,
        price=None,
        amount=None,
        account='normal',
        time_in_force='gtc',
        local_vars_configuration=None,
    ):  # noqa: E501
        # type: (str, str, str, str, str, str, Configuration) -> None
        """SpotPricePutOrder - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._type = None
        self._side = None
        self._price = None
        self._amount = None
        self._account = None
        self._time_in_force = None
        self.discriminator = None

        if type is not None:
            self.type = type
        self.side = side
        self.price = price
        self.amount = amount
        self.account = account
        if time_in_force is not None:
            self.time_in_force = time_in_force

    @property
    def type(self):
        """Gets the type of this SpotPricePutOrder.  # noqa: E501

        Order type, default to `limit`  # noqa: E501

        :return: The type of this SpotPricePutOrder.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this SpotPricePutOrder.

        Order type, default to `limit`  # noqa: E501

        :param type: The type of this SpotPricePutOrder.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def side(self):
        """Gets the side of this SpotPricePutOrder.  # noqa: E501

        Order side  - buy: buy side - sell: sell side  # noqa: E501

        :return: The side of this SpotPricePutOrder.  # noqa: E501
        :rtype: str
        """
        return self._side

    @side.setter
    def side(self, side):
        """Sets the side of this SpotPricePutOrder.

        Order side  - buy: buy side - sell: sell side  # noqa: E501

        :param side: The side of this SpotPricePutOrder.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and side is None:  # noqa: E501
            raise ValueError("Invalid value for `side`, must not be `None`")  # noqa: E501
        allowed_values = ["buy", "sell"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and side not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `side` ({0}), must be one of {1}".format(side, allowed_values)  # noqa: E501
            )

        self._side = side

    @property
    def price(self):
        """Gets the price of this SpotPricePutOrder.  # noqa: E501

        Order price  # noqa: E501

        :return: The price of this SpotPricePutOrder.  # noqa: E501
        :rtype: str
        """
        return self._price

    @price.setter
    def price(self, price):
        """Sets the price of this SpotPricePutOrder.

        Order price  # noqa: E501

        :param price: The price of this SpotPricePutOrder.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and price is None:  # noqa: E501
            raise ValueError("Invalid value for `price`, must not be `None`")  # noqa: E501

        self._price = price

    @property
    def amount(self):
        """Gets the amount of this SpotPricePutOrder.  # noqa: E501

        Order amount  # noqa: E501

        :return: The amount of this SpotPricePutOrder.  # noqa: E501
        :rtype: str
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this SpotPricePutOrder.

        Order amount  # noqa: E501

        :param amount: The amount of this SpotPricePutOrder.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and amount is None:  # noqa: E501
            raise ValueError("Invalid value for `amount`, must not be `None`")  # noqa: E501

        self._amount = amount

    @property
    def account(self):
        """Gets the account of this SpotPricePutOrder.  # noqa: E501

        Trading type  - normal: spot trading - margin: margin trading  # noqa: E501

        :return: The account of this SpotPricePutOrder.  # noqa: E501
        :rtype: str
        """
        return self._account

    @account.setter
    def account(self, account):
        """Sets the account of this SpotPricePutOrder.

        Trading type  - normal: spot trading - margin: margin trading  # noqa: E501

        :param account: The account of this SpotPricePutOrder.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and account is None:  # noqa: E501
            raise ValueError("Invalid value for `account`, must not be `None`")  # noqa: E501
        allowed_values = ["normal", "margin"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and account not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `account` ({0}), must be one of {1}".format(account, allowed_values)  # noqa: E501
            )

        self._account = account

    @property
    def time_in_force(self):
        """Gets the time_in_force of this SpotPricePutOrder.  # noqa: E501

        time_in_force  - gtc: GoodTillCancelled - ioc: ImmediateOrCancelled, taker only   # noqa: E501

        :return: The time_in_force of this SpotPricePutOrder.  # noqa: E501
        :rtype: str
        """
        return self._time_in_force

    @time_in_force.setter
    def time_in_force(self, time_in_force):
        """Sets the time_in_force of this SpotPricePutOrder.

        time_in_force  - gtc: GoodTillCancelled - ioc: ImmediateOrCancelled, taker only   # noqa: E501

        :param time_in_force: The time_in_force of this SpotPricePutOrder.  # noqa: E501
        :type: str
        """
        allowed_values = ["gtc", "ioc"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and time_in_force not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `time_in_force` ({0}), must be one of {1}".format(  # noqa: E501
                    time_in_force, allowed_values
                )
            )

        self._time_in_force = time_in_force

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict()) if hasattr(item[1], "to_dict") else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SpotPricePutOrder):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SpotPricePutOrder):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Gate API v4

    Welcome to Gate.io API  APIv4 provides spot, margin and futures trading operations. There are public APIs to retrieve the real-time market statistics, and private APIs which needs authentication to trade on user's behalf.  # noqa: E501

    Contact: support@mail.gate.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from gate_api.configuration import Configuration


class LoanPatch(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {'currency': 'str', 'side': 'str', 'auto_renew': 'bool', 'currency_pair': 'str', 'loan_id': 'str'}

    attribute_map = {
        'currency': 'currency',
        'side': 'side',
        'auto_renew': 'auto_renew',
        'currency_pair': 'currency_pair',
        'loan_id': 'loan_id',
    }

    def __init__(
        self, currency=None, side=None, auto_renew=None, currency_pair=None, loan_id=None, local_vars_configuration=None
    ):  # noqa: E501
        # type: (str, str, bool, str, str, Configuration) -> None
        """LoanPatch - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._currency = None
        self._side = None
        self._auto_renew = None
        self._currency_pair = None
        self._loan_id = None
        self.discriminator = None

        self.currency = currency
        self.side = side
        self.auto_renew = auto_renew
        if currency_pair is not None:
            self.currency_pair = currency_pair
        if loan_id is not None:
            self.loan_id = loan_id

    @property
    def currency(self):
        """Gets the currency of this LoanPatch.  # noqa: E501

        Loan currency  # noqa: E501

        :return: The currency of this LoanPatch.  # noqa: E501
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this LoanPatch.

        Loan currency  # noqa: E501

        :param currency: The currency of this LoanPatch.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and currency is None:  # noqa: E501
            raise ValueError("Invalid value for `currency`, must not be `None`")  # noqa: E501

        self._currency = currency

    @property
    def side(self):
        """Gets the side of this LoanPatch.  # noqa: E501

        Loan side. Possible values are `lend` and `borrow`. For `LoanRecord` patching, only `lend` is supported  # noqa: E501

        :return: The side of this LoanPatch.  # noqa: E501
        :rtype: str
        """
        return self._side

    @side.setter
    def side(self, side):
        """Sets the side of this LoanPatch.

        Loan side. Possible values are `lend` and `borrow`. For `LoanRecord` patching, only `lend` is supported  # noqa: E501

        :param side: The side of this LoanPatch.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and side is None:  # noqa: E501
            raise ValueError("Invalid value for `side`, must not be `None`")  # noqa: E501
        allowed_values = ["lend", "borrow"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and side not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `side` ({0}), must be one of {1}".format(side, allowed_values)  # noqa: E501
            )

        self._side = side

    @property
    def auto_renew(self):
        """Gets the auto_renew of this LoanPatch.  # noqa: E501

        Auto renew  # noqa: E501

        :return: The auto_renew of this LoanPatch.  # noqa: E501
        :rtype: bool
        """
        return self._auto_renew

    @auto_renew.setter
    def auto_renew(self, auto_renew):
        """Sets the auto_renew of this LoanPatch.

        Auto renew  # noqa: E501

        :param auto_renew: The auto_renew of this LoanPatch.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and auto_renew is None:  # noqa: E501
            raise ValueError("Invalid value for `auto_renew`, must not be `None`")  # noqa: E501

        self._auto_renew = auto_renew

    @property
    def currency_pair(self):
        """Gets the currency_pair of this LoanPatch.  # noqa: E501

        Currency pair. Required if borrowing  # noqa: E501

        :return: The currency_pair of this LoanPatch.  # noqa: E501
        :rtype: str
        """
        return self._currency_pair

    @currency_pair.setter
    def currency_pair(self, currency_pair):
        """Sets the currency_pair of this LoanPatch.

        Currency pair. Required if borrowing  # noqa: E501

        :param currency_pair: The currency_pair of this LoanPatch.  # noqa: E501
        :type: str
        """

        self._currency_pair = currency_pair

    @property
    def loan_id(self):
        """Gets the loan_id of this LoanPatch.  # noqa: E501

        Loan ID. Required for `LoanRecord` patching  # noqa: E501

        :return: The loan_id of this LoanPatch.  # noqa: E501
        :rtype: str
        """
        return self._loan_id

    @loan_id.setter
    def loan_id(self, loan_id):
        """Sets the loan_id of this LoanPatch.

        Loan ID. Required for `LoanRecord` patching  # noqa: E501

        :param loan_id: The loan_id of this LoanPatch.  # noqa: E501
        :type: str
        """

        self._loan_id = loan_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict()) if hasattr(item[1], "to_dict") else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LoanPatch):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, LoanPatch):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Gate API v4

    Welcome to Gate.io API  APIv4 provides spot, margin and futures trading operations. There are public APIs to retrieve the real-time market statistics, and private APIs which needs authentication to trade on user's behalf.  # noqa: E501

    Contact: support@mail.gate.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from gate_api.configuration import Configuration


class Currency(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'currency': 'str',
        'delisted': 'bool',
        'withdraw_disabled': 'bool',
        'withdraw_delayed': 'bool',
        'deposit_disabled': 'bool',
        'trade_disabled': 'bool',
        'fixed_rate': 'str',
    }

    attribute_map = {
        'currency': 'currency',
        'delisted': 'delisted',
        'withdraw_disabled': 'withdraw_disabled',
        'withdraw_delayed': 'withdraw_delayed',
        'deposit_disabled': 'deposit_disabled',
        'trade_disabled': 'trade_disabled',
        'fixed_rate': 'fixed_rate',
    }

    def __init__(
        self,
        currency=None,
        delisted=None,
        withdraw_disabled=None,
        withdraw_delayed=None,
        deposit_disabled=None,
        trade_disabled=None,
        fixed_rate=None,
        local_vars_configuration=None,
    ):  # noqa: E501
        # type: (str, bool, bool, bool, bool, bool, str, Configuration) -> None
        """Currency - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._currency = None
        self._delisted = None
        self._withdraw_disabled = None
        self._withdraw_delayed = None
        self._deposit_disabled = None
        self._trade_disabled = None
        self._fixed_rate = None
        self.discriminator = None

        if currency is not None:
            self.currency = currency
        if delisted is not None:
            self.delisted = delisted
        if withdraw_disabled is not None:
            self.withdraw_disabled = withdraw_disabled
        if withdraw_delayed is not None:
            self.withdraw_delayed = withdraw_delayed
        if deposit_disabled is not None:
            self.deposit_disabled = deposit_disabled
        if trade_disabled is not None:
            self.trade_disabled = trade_disabled
        if fixed_rate is not None:
            self.fixed_rate = fixed_rate

    @property
    def currency(self):
        """Gets the currency of this Currency.  # noqa: E501

        Currency name  # noqa: E501

        :return: The currency of this Currency.  # noqa: E501
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this Currency.

        Currency name  # noqa: E501

        :param currency: The currency of this Currency.  # noqa: E501
        :type: str
        """

        self._currency = currency

    @property
    def delisted(self):
        """Gets the delisted of this Currency.  # noqa: E501

        Whether currency is de-listed  # noqa: E501

        :return: The delisted of this Currency.  # noqa: E501
        :rtype: bool
        """
        return self._delisted

    @delisted.setter
    def delisted(self, delisted):
        """Sets the delisted of this Currency.

        Whether currency is de-listed  # noqa: E501

        :param delisted: The delisted of this Currency.  # noqa: E501
        :type: bool
        """

        self._delisted = delisted

    @property
    def withdraw_disabled(self):
        """Gets the withdraw_disabled of this Currency.  # noqa: E501

        Whether currency's withdrawal is disabled  # noqa: E501

        :return: The withdraw_disabled of this Currency.  # noqa: E501
        :rtype: bool
        """
        return self._withdraw_disabled

    @withdraw_disabled.setter
    def withdraw_disabled(self, withdraw_disabled):
        """Sets the withdraw_disabled of this Currency.

        Whether currency's withdrawal is disabled  # noqa: E501

        :param withdraw_disabled: The withdraw_disabled of this Currency.  # noqa: E501
        :type: bool
        """

        self._withdraw_disabled = withdraw_disabled

    @property
    def withdraw_delayed(self):
        """Gets the withdraw_delayed of this Currency.  # noqa: E501

        Whether currency's withdrawal is delayed  # noqa: E501

        :return: The withdraw_delayed of this Currency.  # noqa: E501
        :rtype: bool
        """
        return self._withdraw_delayed

    @withdraw_delayed.setter
    def withdraw_delayed(self, withdraw_delayed):
        """Sets the withdraw_delayed of this Currency.

        Whether currency's withdrawal is delayed  # noqa: E501

        :param withdraw_delayed: The withdraw_delayed of this Currency.  # noqa: E501
        :type: bool
        """

        self._withdraw_delayed = withdraw_delayed

    @property
    def deposit_disabled(self):
        """Gets the deposit_disabled of this Currency.  # noqa: E501

        Whether currency's deposit is disabled  # noqa: E501

        :return: The deposit_disabled of this Currency.  # noqa: E501
        :rtype: bool
        """
        return self._deposit_disabled

    @deposit_disabled.setter
    def deposit_disabled(self, deposit_disabled):
        """Sets the deposit_disabled of this Currency.

        Whether currency's deposit is disabled  # noqa: E501

        :param deposit_disabled: The deposit_disabled of this Currency.  # noqa: E501
        :type: bool
        """

        self._deposit_disabled = deposit_disabled

    @property
    def trade_disabled(self):
        """Gets the trade_disabled of this Currency.  # noqa: E501

        Whether currency's trading is disabled  # noqa: E501

        :return: The trade_disabled of this Currency.  # noqa: E501
        :rtype: bool
        """
        return self._trade_disabled

    @trade_disabled.setter
    def trade_disabled(self, trade_disabled):
        """Sets the trade_disabled of this Currency.

        Whether currency's trading is disabled  # noqa: E501

        :param trade_disabled: The trade_disabled of this Currency.  # noqa: E501
        :type: bool
        """

        self._trade_disabled = trade_disabled

    @property
    def fixed_rate(self):
        """Gets the fixed_rate of this Currency.  # noqa: E501

        Fixed fee rate. Only for fixed rate currencies, not valid for normal currencies  # noqa: E501

        :return: The fixed_rate of this Currency.  # noqa: E501
        :rtype: str
        """
        return self._fixed_rate

    @fixed_rate.setter
    def fixed_rate(self, fixed_rate):
        """Sets the fixed_rate of this Currency.

        Fixed fee rate. Only for fixed rate currencies, not valid for normal currencies  # noqa: E501

        :param fixed_rate: The fixed_rate of this Currency.  # noqa: E501
        :type: str
        """

        self._fixed_rate = fixed_rate

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict()) if hasattr(item[1], "to_dict") else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Currency):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Currency):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Gate API v4

    Welcome to Gate.io API  APIv4 provides spot, margin and futures trading operations. There are public APIs to retrieve the real-time market statistics, and private APIs which needs authentication to trade on user's behalf.  # noqa: E501

    Contact: support@mail.gate.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from gate_api.configuration import Configuration


class Position(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'user': 'int',
        'contract': 'str',
        'size': 'int',
        'leverage': 'str',
        'risk_limit': 'str',
        'leverage_max': 'str',
        'maintenance_rate': 'str',
        'value': 'str',
        'margin': 'str',
        'entry_price': 'str',
        'liq_price': 'str',
        'mark_price': 'str',
        'unrealised_pnl': 'str',
        'realised_pnl': 'str',
        'history_pnl': 'str',
        'last_close_pnl': 'str',
        'realised_point': 'str',
        'history_point': 'str',
        'adl_ranking': 'int',
        'pending_orders': 'int',
        'close_order': 'PositionCloseOrder',
        'mode': 'str',
        'cross_leverage_limit': 'str',
    }

    attribute_map = {
        'user': 'user',
        'contract': 'contract',
        'size': 'size',
        'leverage': 'leverage',
        'risk_limit': 'risk_limit',
        'leverage_max': 'leverage_max',
        'maintenance_rate': 'maintenance_rate',
        'value': 'value',
        'margin': 'margin',
        'entry_price': 'entry_price',
        'liq_price': 'liq_price',
        'mark_price': 'mark_price',
        'unrealised_pnl': 'unrealised_pnl',
        'realised_pnl': 'realised_pnl',
        'history_pnl': 'history_pnl',
        'last_close_pnl': 'last_close_pnl',
        'realised_point': 'realised_point',
        'history_point': 'history_point',
        'adl_ranking': 'adl_ranking',
        'pending_orders': 'pending_orders',
        'close_order': 'close_order',
        'mode': 'mode',
        'cross_leverage_limit': 'cross_leverage_limit',
    }

    def __init__(
        self,
        user=None,
        contract=None,
        size=None,
        leverage=None,
        risk_limit=None,
        leverage_max=None,
        maintenance_rate=None,
        value=None,
        margin=None,
        entry_price=None,
        liq_price=None,
        mark_price=None,
        unrealised_pnl=None,
        realised_pnl=None,
        history_pnl=None,
        last_close_pnl=None,
        realised_point=None,
        history_point=None,
        adl_ranking=None,
        pending_orders=None,
        close_order=None,
        mode=None,
        cross_leverage_limit=None,
        local_vars_configuration=None,
    ):  # noqa: E501
        # type: (int, str, int, str, str, str, str, str, str, str, str, str, str, str, str, str, str, str, int, int, PositionCloseOrder, str, str, Configuration) -> None
        """Position - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._user = None
        self._contract = None
        self._size = None
        self._leverage = None
        self._risk_limit = None
        self._leverage_max = None
        self._maintenance_rate = None
        self._value = None
        self._margin = None
        self._entry_price = None
        self._liq_price = None
        self._mark_price = None
        self._unrealised_pnl = None
        self._realised_pnl = None
        self._history_pnl = None
        self._last_close_pnl = None
        self._realised_point = None
        self._history_point = None
        self._adl_ranking = None
        self._pending_orders = None
        self._close_order = None
        self._mode = None
        self._cross_leverage_limit = None
        self.discriminator = None

        if user is not None:
            self.user = user
        if contract is not None:
            self.contract = contract
        if size is not None:
            self.size = size
        if leverage is not None:
            self.leverage = leverage
        if risk_limit is not None:
            self.risk_limit = risk_limit
        if leverage_max is not None:
            self.leverage_max = leverage_max
        if maintenance_rate is not None:
            self.maintenance_rate = maintenance_rate
        if value is not None:
            self.value = value
        if margin is not None:
            self.margin = margin
        if entry_price is not None:
            self.entry_price = entry_price
        if liq_price is not None:
            self.liq_price = liq_price
        if mark_price is not None:
            self.mark_price = mark_price
        if unrealised_pnl is not None:
            self.unrealised_pnl = unrealised_pnl
        if realised_pnl is not None:
            self.realised_pnl = realised_pnl
        if history_pnl is not None:
            self.history_pnl = history_pnl
        if last_close_pnl is not None:
            self.last_close_pnl = last_close_pnl
        if realised_point is not None:
            self.realised_point = realised_point
        if history_point is not None:
            self.history_point = history_point
        if adl_ranking is not None:
            self.adl_ranking = adl_ranking
        if pending_orders is not None:
            self.pending_orders = pending_orders
        self.close_order = close_order
        if mode is not None:
            self.mode = mode
        if cross_leverage_limit is not None:
            self.cross_leverage_limit = cross_leverage_limit

    @property
    def user(self):
        """Gets the user of this Position.  # noqa: E501

        User ID  # noqa: E501

        :return: The user of this Position.  # noqa: E501
        :rtype: int
        """
        return self._user

    @user.setter
    def user(self, user):
        """Sets the user of this Position.

        User ID  # noqa: E501

        :param user: The user of this Position.  # noqa: E501
        :type: int
        """

        self._user = user

    @property
    def contract(self):
        """Gets the contract of this Position.  # noqa: E501

        Futures contract  # noqa: E501

        :return: The contract of this Position.  # noqa: E501
        :rtype: str
        """
        return self._contract

    @contract.setter
    def contract(self, contract):
        """Sets the contract of this Position.

        Futures contract  # noqa: E501

        :param contract: The contract of this Position.  # noqa: E501
        :type: str
        """

        self._contract = contract

    @property
    def size(self):
        """Gets the size of this Position.  # noqa: E501

        Position size  # noqa: E501

        :return: The size of this Position.  # noqa: E501
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this Position.

        Position size  # noqa: E501

        :param size: The size of this Position.  # noqa: E501
        :type: int
        """

        self._size = size

    @property
    def leverage(self):
        """Gets the leverage of this Position.  # noqa: E501

        Position leverage. 0 means cross margin; positive number means isolated margin  # noqa: E501

        :return: The leverage of this Position.  # noqa: E501
        :rtype: str
        """
        return self._leverage

    @leverage.setter
    def leverage(self, leverage):
        """Sets the leverage of this Position.

        Position leverage. 0 means cross margin; positive number means isolated margin  # noqa: E501

        :param leverage: The leverage of this Position.  # noqa: E501
        :type: str
        """

        self._leverage = leverage

    @property
    def risk_limit(self):
        """Gets the risk_limit of this Position.  # noqa: E501

        Position risk limit  # noqa: E501

        :return: The risk_limit of this Position.  # noqa: E501
        :rtype: str
        """
        return self._risk_limit

    @risk_limit.setter
    def risk_limit(self, risk_limit):
        """Sets the risk_limit of this Position.

        Position risk limit  # noqa: E501

        :param risk_limit: The risk_limit of this Position.  # noqa: E501
        :type: str
        """

        self._risk_limit = risk_limit

    @property
    def leverage_max(self):
        """Gets the leverage_max of this Position.  # noqa: E501

        Maximum leverage under current risk limit  # noqa: E501

        :return: The leverage_max of this Position.  # noqa: E501
        :rtype: str
        """
        return self._leverage_max

    @leverage_max.setter
    def leverage_max(self, leverage_max):
        """Sets the leverage_max of this Position.

        Maximum leverage under current risk limit  # noqa: E501

        :param leverage_max: The leverage_max of this Position.  # noqa: E501
        :type: str
        """

        self._leverage_max = leverage_max

    @property
    def maintenance_rate(self):
        """Gets the maintenance_rate of this Position.  # noqa: E501

        Maintenance rate under current risk limit  # noqa: E501

        :return: The maintenance_rate of this Position.  # noqa: E501
        :rtype: str
        """
        return self._maintenance_rate

    @maintenance_rate.setter
    def maintenance_rate(self, maintenance_rate):
        """Sets the maintenance_rate of this Position.

        Maintenance rate under current risk limit  # noqa: E501

        :param maintenance_rate: The maintenance_rate of this Position.  # noqa: E501
        :type: str
        """

        self._maintenance_rate = maintenance_rate

    @property
    def value(self):
        """Gets the value of this Position.  # noqa: E501

        Position value calculated in settlement currency  # noqa: E501

        :return: The value of this Position.  # noqa: E501
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this Position.

        Position value calculated in settlement currency  # noqa: E501

        :param value: The value of this Position.  # noqa: E501
        :type: str
        """

        self._value = value

    @property
    def margin(self):
        """Gets the margin of this Position.  # noqa: E501

        Position margin  # noqa: E501

        :return: The margin of this Position.  # noqa: E501
        :rtype: str
        """
        return self._margin

    @margin.setter
    def margin(self, margin):
        """Sets the margin of this Position.

        Position margin  # noqa: E501

        :param margin: The margin of this Position.  # noqa: E501
        :type: str
        """

        self._margin = margin

    @property
    def entry_price(self):
        """Gets the entry_price of this Position.  # noqa: E501

        Entry price  # noqa: E501

        :return: The entry_price of this Position.  # noqa: E501
        :rtype: str
        """
        return self._entry_price

    @entry_price.setter
    def entry_price(self, entry_price):
        """Sets the entry_price of this Position.

        Entry price  # noqa: E501

        :param entry_price: The entry_price of this Position.  # noqa: E501
        :type: str
        """

        self._entry_price = entry_price

    @property
    def liq_price(self):
        """Gets the liq_price of this Position.  # noqa: E501

        Liquidation price  # noqa: E501

        :return: The liq_price of this Position.  # noqa: E501
        :rtype: str
        """
        return self._liq_price

    @liq_price.setter
    def liq_price(self, liq_price):
        """Sets the liq_price of this Position.

        Liquidation price  # noqa: E501

        :param liq_price: The liq_price of this Position.  # noqa: E501
        :type: str
        """

        self._liq_price = liq_price

    @property
    def mark_price(self):
        """Gets the mark_price of this Position.  # noqa: E501

        Current mark price  # noqa: E501

        :return: The mark_price of this Position.  # noqa: E501
        :rtype: str
        """
        return self._mark_price

    @mark_price.setter
    def mark_price(self, mark_price):
        """Sets the mark_price of this Position.

        Current mark price  # noqa: E501

        :param mark_price: The mark_price of this Position.  # noqa: E501
        :type: str
        """

        self._mark_price = mark_price

    @property
    def unrealised_pnl(self):
        """Gets the unrealised_pnl of this Position.  # noqa: E501

        Unrealized PNL  # noqa: E501

        :return: The unrealised_pnl of this Position.  # noqa: E501
        :rtype: str
        """
        return self._unrealised_pnl

    @unrealised_pnl.setter
    def unrealised_pnl(self, unrealised_pnl):
        """Sets the unrealised_pnl of this Position.

        Unrealized PNL  # noqa: E501

        :param unrealised_pnl: The unrealised_pnl of this Position.  # noqa: E501
        :type: str
        """

        self._unrealised_pnl = unrealised_pnl

    @property
    def realised_pnl(self):
        """Gets the realised_pnl of this Position.  # noqa: E501

        Realized PNL  # noqa: E501

        :return: The realised_pnl of this Position.  # noqa: E501
        :rtype: str
        """
        return self._realised_pnl

    @realised_pnl.setter
    def realised_pnl(self, realised_pnl):
        """Sets the realised_pnl of this Position.

        Realized PNL  # noqa: E501

        :param realised_pnl: The realised_pnl of this Position.  # noqa: E501
        :type: str
        """

        self._realised_pnl = realised_pnl

    @property
    def history_pnl(self):
        """Gets the history_pnl of this Position.  # noqa: E501

        History realized PNL  # noqa: E501

        :return: The history_pnl of this Position.  # noqa: E501
        :rtype: str
        """
        return self._history_pnl

    @history_pnl.setter
    def history_pnl(self, history_pnl):
        """Sets the history_pnl of this Position.

        History realized PNL  # noqa: E501

        :param history_pnl: The history_pnl of this Position.  # noqa: E501
        :type: str
        """

        self._history_pnl = history_pnl

    @property
    def last_close_pnl(self):
        """Gets the last_close_pnl of this Position.  # noqa: E501

        PNL of last position close  # noqa: E501

        :return: The last_close_pnl of this Position.  # noqa: E501
        :rtype: str
        """
        return self._last_close_pnl

    @last_close_pnl.setter
    def last_close_pnl(self, last_close_pnl):
        """Sets the last_close_pnl of this Position.

        PNL of last position close  # noqa: E501

        :param last_close_pnl: The last_close_pnl of this Position.  # noqa: E501
        :type: str
        """

        self._last_close_pnl = last_close_pnl

    @property
    def realised_point(self):
        """Gets the realised_point of this Position.  # noqa: E501

        Realized POINT PNL  # noqa: E501

        :return: The realised_point of this Position.  # noqa: E501
        :rtype: str
        """
        return self._realised_point

    @realised_point.setter
    def realised_point(self, realised_point):
        """Sets the realised_point of this Position.

        Realized POINT PNL  # noqa: E501

        :param realised_point: The realised_point of this Position.  # noqa: E501
        :type: str
        """

        self._realised_point = realised_point

    @property
    def history_point(self):
        """Gets the history_point of this Position.  # noqa: E501

        History realized POINT PNL  # noqa: E501

        :return: The history_point of this Position.  # noqa: E501
        :rtype: str
        """
        return self._history_point

    @history_point.setter
    def history_point(self, history_point):
        """Sets the history_point of this Position.

        History realized POINT PNL  # noqa: E501

        :param history_point: The history_point of this Position.  # noqa: E501
        :type: str
        """

        self._history_point = history_point

    @property
    def adl_ranking(self):
        """Gets the adl_ranking of this Position.  # noqa: E501

        ADL ranking, ranging from 1 to 5  # noqa: E501

        :return: The adl_ranking of this Position.  # noqa: E501
        :rtype: int
        """
        return self._adl_ranking

    @adl_ranking.setter
    def adl_ranking(self, adl_ranking):
        """Sets the adl_ranking of this Position.

        ADL ranking, ranging from 1 to 5  # noqa: E501

        :param adl_ranking: The adl_ranking of this Position.  # noqa: E501
        :type: int
        """

        self._adl_ranking = adl_ranking

    @property
    def pending_orders(self):
        """Gets the pending_orders of this Position.  # noqa: E501

        Current open orders  # noqa: E501

        :return: The pending_orders of this Position.  # noqa: E501
        :rtype: int
        """
        return self._pending_orders

    @pending_orders.setter
    def pending_orders(self, pending_orders):
        """Sets the pending_orders of this Position.

        Current open orders  # noqa: E501

        :param pending_orders: The pending_orders of this Position.  # noqa: E501
        :type: int
        """

        self._pending_orders = pending_orders

    @property
    def close_order(self):
        """Gets the close_order of this Position.  # noqa: E501


        :return: The close_order of this Position.  # noqa: E501
        :rtype: PositionCloseOrder
        """
        return self._close_order

    @close_order.setter
    def close_order(self, close_order):
        """Sets the close_order of this Position.


        :param close_order: The close_order of this Position.  # noqa: E501
        :type: PositionCloseOrder
        """

        self._close_order = close_order

    @property
    def mode(self):
        """Gets the mode of this Position.  # noqa: E501

        Position mode, including:  - `single`: dual mode is not enabled- `dual_long`: long position in dual mode- `dual_short`: short position in dual mode  # noqa: E501

        :return: The mode of this Position.  # noqa: E501
        :rtype: str
        """
        return self._mode

    @mode.setter
    def mode(self, mode):
        """Sets the mode of this Position.

        Position mode, including:  - `single`: dual mode is not enabled- `dual_long`: long position in dual mode- `dual_short`: short position in dual mode  # noqa: E501

        :param mode: The mode of this Position.  # noqa: E501
        :type: str
        """
        allowed_values = ["single", "dual_long", "dual_short"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and mode not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `mode` ({0}), must be one of {1}".format(mode, allowed_values)  # noqa: E501
            )

        self._mode = mode

    @property
    def cross_leverage_limit(self):
        """Gets the cross_leverage_limit of this Position.  # noqa: E501

        Cross margin leverage(valid only when `leverage` is 0)  # noqa: E501

        :return: The cross_leverage_limit of this Position.  # noqa: E501
        :rtype: str
        """
        return self._cross_leverage_limit

    @cross_leverage_limit.setter
    def cross_leverage_limit(self, cross_leverage_limit):
        """Sets the cross_leverage_limit of this Position.

        Cross margin leverage(valid only when `leverage` is 0)  # noqa: E501

        :param cross_leverage_limit: The cross_leverage_limit of this Position.  # noqa: E501
        :type: str
        """

        self._cross_leverage_limit = cross_leverage_limit

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict()) if hasattr(item[1], "to_dict") else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Position):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Position):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Gate API v4

    Welcome to Gate.io API  APIv4 provides spot, margin and futures trading operations. There are public APIs to retrieve the real-time market statistics, and private APIs which needs authentication to trade on user's behalf.  # noqa: E501

    Contact: support@mail.gate.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from gate_api.configuration import Configuration


class FuturesPriceTriggeredOrder(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'initial': 'FuturesInitialOrder',
        'trigger': 'FuturesPriceTrigger',
        'id': 'int',
        'user': 'int',
        'create_time': 'float',
        'finish_time': 'float',
        'trade_id': 'int',
        'status': 'str',
        'finish_as': 'str',
        'reason': 'str',
    }

    attribute_map = {
        'initial': 'initial',
        'trigger': 'trigger',
        'id': 'id',
        'user': 'user',
        'create_time': 'create_time',
        'finish_time': 'finish_time',
        'trade_id': 'trade_id',
        'status': 'status',
        'finish_as': 'finish_as',
        'reason': 'reason',
    }

    def __init__(
        self,
        initial=None,
        trigger=None,
        id=None,
        user=None,
        create_time=None,
        finish_time=None,
        trade_id=None,
        status=None,
        finish_as=None,
        reason=None,
        local_vars_configuration=None,
    ):  # noqa: E501
        # type: (FuturesInitialOrder, FuturesPriceTrigger, int, int, float, float, int, str, str, str, Configuration) -> None
        """FuturesPriceTriggeredOrder - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._initial = None
        self._trigger = None
        self._id = None
        self._user = None
        self._create_time = None
        self._finish_time = None
        self._trade_id = None
        self._status = None
        self._finish_as = None
        self._reason = None
        self.discriminator = None

        self.initial = initial
        self.trigger = trigger
        if id is not None:
            self.id = id
        if user is not None:
            self.user = user
        if create_time is not None:
            self.create_time = create_time
        if finish_time is not None:
            self.finish_time = finish_time
        if trade_id is not None:
            self.trade_id = trade_id
        if status is not None:
            self.status = status
        if finish_as is not None:
            self.finish_as = finish_as
        if reason is not None:
            self.reason = reason

    @property
    def initial(self):
        """Gets the initial of this FuturesPriceTriggeredOrder.  # noqa: E501


        :return: The initial of this FuturesPriceTriggeredOrder.  # noqa: E501
        :rtype: FuturesInitialOrder
        """
        return self._initial

    @initial.setter
    def initial(self, initial):
        """Sets the initial of this FuturesPriceTriggeredOrder.


        :param initial: The initial of this FuturesPriceTriggeredOrder.  # noqa: E501
        :type: FuturesInitialOrder
        """
        if self.local_vars_configuration.client_side_validation and initial is None:  # noqa: E501
            raise ValueError("Invalid value for `initial`, must not be `None`")  # noqa: E501

        self._initial = initial

    @property
    def trigger(self):
        """Gets the trigger of this FuturesPriceTriggeredOrder.  # noqa: E501


        :return: The trigger of this FuturesPriceTriggeredOrder.  # noqa: E501
        :rtype: FuturesPriceTrigger
        """
        return self._trigger

    @trigger.setter
    def trigger(self, trigger):
        """Sets the trigger of this FuturesPriceTriggeredOrder.


        :param trigger: The trigger of this FuturesPriceTriggeredOrder.  # noqa: E501
        :type: FuturesPriceTrigger
        """
        if self.local_vars_configuration.client_side_validation and trigger is None:  # noqa: E501
            raise ValueError("Invalid value for `trigger`, must not be `None`")  # noqa: E501

        self._trigger = trigger

    @property
    def id(self):
        """Gets the id of this FuturesPriceTriggeredOrder.  # noqa: E501

        Auto order ID  # noqa: E501

        :return: The id of this FuturesPriceTriggeredOrder.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this FuturesPriceTriggeredOrder.

        Auto order ID  # noqa: E501

        :param id: The id of this FuturesPriceTriggeredOrder.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def user(self):
        """Gets the user of this FuturesPriceTriggeredOrder.  # noqa: E501

        User ID  # noqa: E501

        :return: The user of this FuturesPriceTriggeredOrder.  # noqa: E501
        :rtype: int
        """
        return self._user

    @user.setter
    def user(self, user):
        """Sets the user of this FuturesPriceTriggeredOrder.

        User ID  # noqa: E501

        :param user: The user of this FuturesPriceTriggeredOrder.  # noqa: E501
        :type: int
        """

        self._user = user

    @property
    def create_time(self):
        """Gets the create_time of this FuturesPriceTriggeredOrder.  # noqa: E501

        Creation time  # noqa: E501

        :return: The create_time of this FuturesPriceTriggeredOrder.  # noqa: E501
        :rtype: float
        """
        return self._create_time

    @create_time.setter
    def create_time(self, create_time):
        """Sets the create_time of this FuturesPriceTriggeredOrder.

        Creation time  # noqa: E501

        :param create_time: The create_time of this FuturesPriceTriggeredOrder.  # noqa: E501
        :type: float
        """

        self._create_time = create_time

    @property
    def finish_time(self):
        """Gets the finish_time of this FuturesPriceTriggeredOrder.  # noqa: E501

        Finished time  # noqa: E501

        :return: The finish_time of this FuturesPriceTriggeredOrder.  # noqa: E501
        :rtype: float
        """
        return self._finish_time

    @finish_time.setter
    def finish_time(self, finish_time):
        """Sets the finish_time of this FuturesPriceTriggeredOrder.

        Finished time  # noqa: E501

        :param finish_time: The finish_time of this FuturesPriceTriggeredOrder.  # noqa: E501
        :type: float
        """

        self._finish_time = finish_time

    @property
    def trade_id(self):
        """Gets the trade_id of this FuturesPriceTriggeredOrder.  # noqa: E501

        ID of the newly created order on condition triggered  # noqa: E501

        :return: The trade_id of this FuturesPriceTriggeredOrder.  # noqa: E501
        :rtype: int
        """
        return self._trade_id

    @trade_id.setter
    def trade_id(self, trade_id):
        """Sets the trade_id of this FuturesPriceTriggeredOrder.

        ID of the newly created order on condition triggered  # noqa: E501

        :param trade_id: The trade_id of this FuturesPriceTriggeredOrder.  # noqa: E501
        :type: int
        """

        self._trade_id = trade_id

    @property
    def status(self):
        """Gets the status of this FuturesPriceTriggeredOrder.  # noqa: E501

        Order status.  # noqa: E501

        :return: The status of this FuturesPriceTriggeredOrder.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this FuturesPriceTriggeredOrder.

        Order status.  # noqa: E501

        :param status: The status of this FuturesPriceTriggeredOrder.  # noqa: E501
        :type: str
        """
        allowed_values = ["open", "finished"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and status not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}".format(status, allowed_values)  # noqa: E501
            )

        self._status = status

    @property
    def finish_as(self):
        """Gets the finish_as of this FuturesPriceTriggeredOrder.  # noqa: E501

        How order is finished  # noqa: E501

        :return: The finish_as of this FuturesPriceTriggeredOrder.  # noqa: E501
        :rtype: str
        """
        return self._finish_as

    @finish_as.setter
    def finish_as(self, finish_as):
        """Sets the finish_as of this FuturesPriceTriggeredOrder.

        How order is finished  # noqa: E501

        :param finish_as: The finish_as of this FuturesPriceTriggeredOrder.  # noqa: E501
        :type: str
        """
        allowed_values = ["cancelled", "succeeded", "failed", "expired"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and finish_as not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `finish_as` ({0}), must be one of {1}".format(  # noqa: E501
                    finish_as, allowed_values
                )
            )

        self._finish_as = finish_as

    @property
    def reason(self):
        """Gets the reason of this FuturesPriceTriggeredOrder.  # noqa: E501

        Additional remarks on how the order was finished  # noqa: E501

        :return: The reason of this FuturesPriceTriggeredOrder.  # noqa: E501
        :rtype: str
        """
        return self._reason

    @reason.setter
    def reason(self, reason):
        """Sets the reason of this FuturesPriceTriggeredOrder.

        Additional remarks on how the order was finished  # noqa: E501

        :param reason: The reason of this FuturesPriceTriggeredOrder.  # noqa: E501
        :type: str
        """

        self._reason = reason

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict()) if hasattr(item[1], "to_dict") else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FuturesPriceTriggeredOrder):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, FuturesPriceTriggeredOrder):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Gate API v4

    Welcome to Gate.io API  APIv4 provides spot, margin and futures trading operations. There are public APIs to retrieve the real-time market statistics, and private APIs which needs authentication to trade on user's behalf.  # noqa: E501

    Contact: support@mail.gate.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from gate_api.configuration import Configuration


class ContractStat(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'time': 'int',
        'lsr_taker': 'float',
        'lsr_account': 'float',
        'long_liq_size': 'int',
        'long_liq_amount': 'float',
        'long_liq_usd': 'float',
        'short_liq_size': 'int',
        'short_liq_amount': 'float',
        'short_liq_usd': 'float',
        'open_interest': 'int',
        'open_interest_usd': 'float',
        'top_lsr_account': 'float',
        'top_lsr_size': 'float',
    }

    attribute_map = {
        'time': 'time',
        'lsr_taker': 'lsr_taker',
        'lsr_account': 'lsr_account',
        'long_liq_size': 'long_liq_size',
        'long_liq_amount': 'long_liq_amount',
        'long_liq_usd': 'long_liq_usd',
        'short_liq_size': 'short_liq_size',
        'short_liq_amount': 'short_liq_amount',
        'short_liq_usd': 'short_liq_usd',
        'open_interest': 'open_interest',
        'open_interest_usd': 'open_interest_usd',
        'top_lsr_account': 'top_lsr_account',
        'top_lsr_size': 'top_lsr_size',
    }

    def __init__(
        self,
        time=None,
        lsr_taker=None,
        lsr_account=None,
        long_liq_size=None,
        long_liq_amount=None,
        long_liq_usd=None,
        short_liq_size=None,
        short_liq_amount=None,
        short_liq_usd=None,
        open_interest=None,
        open_interest_usd=None,
        top_lsr_account=None,
        top_lsr_size=None,
        local_vars_configuration=None,
    ):  # noqa: E501
        # type: (int, float, float, int, float, float, int, float, float, int, float, float, float, Configuration) -> None
        """ContractStat - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._time = None
        self._lsr_taker = None
        self._lsr_account = None
        self._long_liq_size = None
        self._long_liq_amount = None
        self._long_liq_usd = None
        self._short_liq_size = None
        self._short_liq_amount = None
        self._short_liq_usd = None
        self._open_interest = None
        self._open_interest_usd = None
        self._top_lsr_account = None
        self._top_lsr_size = None
        self.discriminator = None

        if time is not None:
            self.time = time
        if lsr_taker is not None:
            self.lsr_taker = lsr_taker
        if lsr_account is not None:
            self.lsr_account = lsr_account
        if long_liq_size is not None:
            self.long_liq_size = long_liq_size
        if long_liq_amount is not None:
            self.long_liq_amount = long_liq_amount
        if long_liq_usd is not None:
            self.long_liq_usd = long_liq_usd
        if short_liq_size is not None:
            self.short_liq_size = short_liq_size
        if short_liq_amount is not None:
            self.short_liq_amount = short_liq_amount
        if short_liq_usd is not None:
            self.short_liq_usd = short_liq_usd
        if open_interest is not None:
            self.open_interest = open_interest
        if open_interest_usd is not None:
            self.open_interest_usd = open_interest_usd
        if top_lsr_account is not None:
            self.top_lsr_account = top_lsr_account
        if top_lsr_size is not None:
            self.top_lsr_size = top_lsr_size

    @property
    def time(self):
        """Gets the time of this ContractStat.  # noqa: E501

        Stat timestamp  # noqa: E501

        :return: The time of this ContractStat.  # noqa: E501
        :rtype: int
        """
        return self._time

    @time.setter
    def time(self, time):
        """Sets the time of this ContractStat.

        Stat timestamp  # noqa: E501

        :param time: The time of this ContractStat.  # noqa: E501
        :type: int
        """

        self._time = time

    @property
    def lsr_taker(self):
        """Gets the lsr_taker of this ContractStat.  # noqa: E501

        Long/short account number ratio  # noqa: E501

        :return: The lsr_taker of this ContractStat.  # noqa: E501
        :rtype: float
        """
        return self._lsr_taker

    @lsr_taker.setter
    def lsr_taker(self, lsr_taker):
        """Sets the lsr_taker of this ContractStat.

        Long/short account number ratio  # noqa: E501

        :param lsr_taker: The lsr_taker of this ContractStat.  # noqa: E501
        :type: float
        """

        self._lsr_taker = lsr_taker

    @property
    def lsr_account(self):
        """Gets the lsr_account of this ContractStat.  # noqa: E501

        Long/short taker size ratio  # noqa: E501

        :return: The lsr_account of this ContractStat.  # noqa: E501
        :rtype: float
        """
        return self._lsr_account

    @lsr_account.setter
    def lsr_account(self, lsr_account):
        """Sets the lsr_account of this ContractStat.

        Long/short taker size ratio  # noqa: E501

        :param lsr_account: The lsr_account of this ContractStat.  # noqa: E501
        :type: float
        """

        self._lsr_account = lsr_account

    @property
    def long_liq_size(self):
        """Gets the long_liq_size of this ContractStat.  # noqa: E501

        Long liquidation size  # noqa: E501

        :return: The long_liq_size of this ContractStat.  # noqa: E501
        :rtype: int
        """
        return self._long_liq_size

    @long_liq_size.setter
    def long_liq_size(self, long_liq_size):
        """Sets the long_liq_size of this ContractStat.

        Long liquidation size  # noqa: E501

        :param long_liq_size: The long_liq_size of this ContractStat.  # noqa: E501
        :type: int
        """

        self._long_liq_size = long_liq_size

    @property
    def long_liq_amount(self):
        """Gets the long_liq_amount of this ContractStat.  # noqa: E501

        Long liquidation amount(base currency)  # noqa: E501

        :return: The long_liq_amount of this ContractStat.  # noqa: E501
        :rtype: float
        """
        return self._long_liq_amount

    @long_liq_amount.setter
    def long_liq_amount(self, long_liq_amount):
        """Sets the long_liq_amount of this ContractStat.

        Long liquidation amount(base currency)  # noqa: E501

        :param long_liq_amount: The long_liq_amount of this ContractStat.  # noqa: E501
        :type: float
        """

        self._long_liq_amount = long_liq_amount

    @property
    def long_liq_usd(self):
        """Gets the long_liq_usd of this ContractStat.  # noqa: E501

        Long liquidation volume(quote currency)  # noqa: E501

        :return: The long_liq_usd of this ContractStat.  # noqa: E501
        :rtype: float
        """
        return self._long_liq_usd

    @long_liq_usd.setter
    def long_liq_usd(self, long_liq_usd):
        """Sets the long_liq_usd of this ContractStat.

        Long liquidation volume(quote currency)  # noqa: E501

        :param long_liq_usd: The long_liq_usd of this ContractStat.  # noqa: E501
        :type: float
        """

        self._long_liq_usd = long_liq_usd

    @property
    def short_liq_size(self):
        """Gets the short_liq_size of this ContractStat.  # noqa: E501

        Short liquidation size  # noqa: E501

        :return: The short_liq_size of this ContractStat.  # noqa: E501
        :rtype: int
        """
        return self._short_liq_size

    @short_liq_size.setter
    def short_liq_size(self, short_liq_size):
        """Sets the short_liq_size of this ContractStat.

        Short liquidation size  # noqa: E501

        :param short_liq_size: The short_liq_size of this ContractStat.  # noqa: E501
        :type: int
        """

        self._short_liq_size = short_liq_size

    @property
    def short_liq_amount(self):
        """Gets the short_liq_amount of this ContractStat.  # noqa: E501

        Short liquidation amount(base currency)  # noqa: E501

        :return: The short_liq_amount of this ContractStat.  # noqa: E501
        :rtype: float
        """
        return self._short_liq_amount

    @short_liq_amount.setter
    def short_liq_amount(self, short_liq_amount):
        """Sets the short_liq_amount of this ContractStat.

        Short liquidation amount(base currency)  # noqa: E501

        :param short_liq_amount: The short_liq_amount of this ContractStat.  # noqa: E501
        :type: float
        """

        self._short_liq_amount = short_liq_amount

    @property
    def short_liq_usd(self):
        """Gets the short_liq_usd of this ContractStat.  # noqa: E501

        Short liquidation volume(quote currency)  # noqa: E501

        :return: The short_liq_usd of this ContractStat.  # noqa: E501
        :rtype: float
        """
        return self._short_liq_usd

    @short_liq_usd.setter
    def short_liq_usd(self, short_liq_usd):
        """Sets the short_liq_usd of this ContractStat.

        Short liquidation volume(quote currency)  # noqa: E501

        :param short_liq_usd: The short_liq_usd of this ContractStat.  # noqa: E501
        :type: float
        """

        self._short_liq_usd = short_liq_usd

    @property
    def open_interest(self):
        """Gets the open_interest of this ContractStat.  # noqa: E501

        Open interest size  # noqa: E501

        :return: The open_interest of this ContractStat.  # noqa: E501
        :rtype: int
        """
        return self._open_interest

    @open_interest.setter
    def open_interest(self, open_interest):
        """Sets the open_interest of this ContractStat.

        Open interest size  # noqa: E501

        :param open_interest: The open_interest of this ContractStat.  # noqa: E501
        :type: int
        """

        self._open_interest = open_interest

    @property
    def open_interest_usd(self):
        """Gets the open_interest_usd of this ContractStat.  # noqa: E501

        Open interest volume(quote currency)  # noqa: E501

        :return: The open_interest_usd of this ContractStat.  # noqa: E501
        :rtype: float
        """
        return self._open_interest_usd

    @open_interest_usd.setter
    def open_interest_usd(self, open_interest_usd):
        """Sets the open_interest_usd of this ContractStat.

        Open interest volume(quote currency)  # noqa: E501

        :param open_interest_usd: The open_interest_usd of this ContractStat.  # noqa: E501
        :type: float
        """

        self._open_interest_usd = open_interest_usd

    @property
    def top_lsr_account(self):
        """Gets the top_lsr_account of this ContractStat.  # noqa: E501

        Top trader long/short account ratio  # noqa: E501

        :return: The top_lsr_account of this ContractStat.  # noqa: E501
        :rtype: float
        """
        return self._top_lsr_account

    @top_lsr_account.setter
    def top_lsr_account(self, top_lsr_account):
        """Sets the top_lsr_account of this ContractStat.

        Top trader long/short account ratio  # noqa: E501

        :param top_lsr_account: The top_lsr_account of this ContractStat.  # noqa: E501
        :type: float
        """

        self._top_lsr_account = top_lsr_account

    @property
    def top_lsr_size(self):
        """Gets the top_lsr_size of this ContractStat.  # noqa: E501

        Top trader long/short position ratio  # noqa: E501

        :return: The top_lsr_size of this ContractStat.  # noqa: E501
        :rtype: float
        """
        return self._top_lsr_size

    @top_lsr_size.setter
    def top_lsr_size(self, top_lsr_size):
        """Sets the top_lsr_size of this ContractStat.

        Top trader long/short position ratio  # noqa: E501

        :param top_lsr_size: The top_lsr_size of this ContractStat.  # noqa: E501
        :type: float
        """

        self._top_lsr_size = top_lsr_size

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict()) if hasattr(item[1], "to_dict") else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ContractStat):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ContractStat):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Gate API v4

    Welcome to Gate.io API  APIv4 provides spot, margin and futures trading operations. There are public APIs to retrieve the real-time market statistics, and private APIs which needs authentication to trade on user's behalf.  # noqa: E501

    Contact: support@mail.gate.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from gate_api.configuration import Configuration


class OptionsOrder(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'int',
        'user': 'int',
        'create_time': 'float',
        'finish_time': 'float',
        'finish_as': 'str',
        'status': 'str',
        'contract': 'str',
        'size': 'int',
        'iceberg': 'int',
        'price': 'str',
        'close': 'bool',
        'is_close': 'bool',
        'reduce_only': 'bool',
        'is_reduce_only': 'bool',
        'is_liq': 'bool',
        'tif': 'str',
        'left': 'int',
        'fill_price': 'str',
        'text': 'str',
        'tkfr': 'str',
        'mkfr': 'str',
        'refu': 'int',
    }

    attribute_map = {
        'id': 'id',
        'user': 'user',
        'create_time': 'create_time',
        'finish_time': 'finish_time',
        'finish_as': 'finish_as',
        'status': 'status',
        'contract': 'contract',
        'size': 'size',
        'iceberg': 'iceberg',
        'price': 'price',
        'close': 'close',
        'is_close': 'is_close',
        'reduce_only': 'reduce_only',
        'is_reduce_only': 'is_reduce_only',
        'is_liq': 'is_liq',
        'tif': 'tif',
        'left': 'left',
        'fill_price': 'fill_price',
        'text': 'text',
        'tkfr': 'tkfr',
        'mkfr': 'mkfr',
        'refu': 'refu',
    }

    def __init__(
        self,
        id=None,
        user=None,
        create_time=None,
        finish_time=None,
        finish_as=None,
        status=None,
        contract=None,
        size=None,
        iceberg=None,
        price=None,
        close=False,
        is_close=None,
        reduce_only=False,
        is_reduce_only=None,
        is_liq=None,
        tif='gtc',
        left=None,
        fill_price=None,
        text=None,
        tkfr=None,
        mkfr=None,
        refu=None,
        local_vars_configuration=None,
    ):  # noqa: E501
        # type: (int, int, float, float, str, str, str, int, int, str, bool, bool, bool, bool, bool, str, int, str, str, str, str, int, Configuration) -> None
        """OptionsOrder - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._user = None
        self._create_time = None
        self._finish_time = None
        self._finish_as = None
        self._status = None
        self._contract = None
        self._size = None
        self._iceberg = None
        self._price = None
        self._close = None
        self._is_close = None
        self._reduce_only = None
        self._is_reduce_only = None
        self._is_liq = None
        self._tif = None
        self._left = None
        self._fill_price = None
        self._text = None
        self._tkfr = None
        self._mkfr = None
        self._refu = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if user is not None:
            self.user = user
        if create_time is not None:
            self.create_time = create_time
        if finish_time is not None:
            self.finish_time = finish_time
        if finish_as is not None:
            self.finish_as = finish_as
        if status is not None:
            self.status = status
        self.contract = contract
        self.size = size
        if iceberg is not None:
            self.iceberg = iceberg
        if price is not None:
            self.price = price
        if close is not None:
            self.close = close
        if is_close is not None:
            self.is_close = is_close
        if reduce_only is not None:
            self.reduce_only = reduce_only
        if is_reduce_only is not None:
            self.is_reduce_only = is_reduce_only
        if is_liq is not None:
            self.is_liq = is_liq
        if tif is not None:
            self.tif = tif
        if left is not None:
            self.left = left
        if fill_price is not None:
            self.fill_price = fill_price
        if text is not None:
            self.text = text
        if tkfr is not None:
            self.tkfr = tkfr
        if mkfr is not None:
            self.mkfr = mkfr
        if refu is not None:
            self.refu = refu

    @property
    def id(self):
        """Gets the id of this OptionsOrder.  # noqa: E501

        Options order ID  # noqa: E501

        :return: The id of this OptionsOrder.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this OptionsOrder.

        Options order ID  # noqa: E501

        :param id: The id of this OptionsOrder.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def user(self):
        """Gets the user of this OptionsOrder.  # noqa: E501

        User ID  # noqa: E501

        :return: The user of this OptionsOrder.  # noqa: E501
        :rtype: int
        """
        return self._user

    @user.setter
    def user(self, user):
        """Sets the user of this OptionsOrder.

        User ID  # noqa: E501

        :param user: The user of this OptionsOrder.  # noqa: E501
        :type: int
        """

        self._user = user

    @property
    def create_time(self):
        """Gets the create_time of this OptionsOrder.  # noqa: E501

        Creation time of order  # noqa: E501

        :return: The create_time of this OptionsOrder.  # noqa: E501
        :rtype: float
        """
        return self._create_time

    @create_time.setter
    def create_time(self, create_time):
        """Sets the create_time of this OptionsOrder.

        Creation time of order  # noqa: E501

        :param create_time: The create_time of this OptionsOrder.  # noqa: E501
        :type: float
        """

        self._create_time = create_time

    @property
    def finish_time(self):
        """Gets the finish_time of this OptionsOrder.  # noqa: E501

        Order finished time. Not returned if order is open  # noqa: E501

        :return: The finish_time of this OptionsOrder.  # noqa: E501
        :rtype: float
        """
        return self._finish_time

    @finish_time.setter
    def finish_time(self, finish_time):
        """Sets the finish_time of this OptionsOrder.

        Order finished time. Not returned if order is open  # noqa: E501

        :param finish_time: The finish_time of this OptionsOrder.  # noqa: E501
        :type: float
        """

        self._finish_time = finish_time

    @property
    def finish_as(self):
        """Gets the finish_as of this OptionsOrder.  # noqa: E501

        How the order was finished.  - filled: all filled - cancelled: manually cancelled - liquidated: cancelled because of liquidation - ioc: time in force is `IOC`, finish immediately - auto_deleveraged: finished by ADL - reduce_only: cancelled because of increasing position while `reduce-only` set- position_closed: cancelled because of position close   # noqa: E501

        :return: The finish_as of this OptionsOrder.  # noqa: E501
        :rtype: str
        """
        return self._finish_as

    @finish_as.setter
    def finish_as(self, finish_as):
        """Sets the finish_as of this OptionsOrder.

        How the order was finished.  - filled: all filled - cancelled: manually cancelled - liquidated: cancelled because of liquidation - ioc: time in force is `IOC`, finish immediately - auto_deleveraged: finished by ADL - reduce_only: cancelled because of increasing position while `reduce-only` set- position_closed: cancelled because of position close   # noqa: E501

        :param finish_as: The finish_as of this OptionsOrder.  # noqa: E501
        :type: str
        """
        allowed_values = [
            "filled",
            "cancelled",
            "liquidated",
            "ioc",
            "auto_deleveraged",
            "reduce_only",
            "position_closed",
            "reduce_out",
        ]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and finish_as not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `finish_as` ({0}), must be one of {1}".format(  # noqa: E501
                    finish_as, allowed_values
                )
            )

        self._finish_as = finish_as

    @property
    def status(self):
        """Gets the status of this OptionsOrder.  # noqa: E501

        Order status  - `open`: waiting to be traded - `finished`: finished  # noqa: E501

        :return: The status of this OptionsOrder.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this OptionsOrder.

        Order status  - `open`: waiting to be traded - `finished`: finished  # noqa: E501

        :param status: The status of this OptionsOrder.  # noqa: E501
        :type: str
        """
        allowed_values = ["open", "finished"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and status not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}".format(status, allowed_values)  # noqa: E501
            )

        self._status = status

    @property
    def contract(self):
        """Gets the contract of this OptionsOrder.  # noqa: E501

        Contract name  # noqa: E501

        :return: The contract of this OptionsOrder.  # noqa: E501
        :rtype: str
        """
        return self._contract

    @contract.setter
    def contract(self, contract):
        """Sets the contract of this OptionsOrder.

        Contract name  # noqa: E501

        :param contract: The contract of this OptionsOrder.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and contract is None:  # noqa: E501
            raise ValueError("Invalid value for `contract`, must not be `None`")  # noqa: E501

        self._contract = contract

    @property
    def size(self):
        """Gets the size of this OptionsOrder.  # noqa: E501

        Order size. Specify positive number to make a bid, and negative number to ask  # noqa: E501

        :return: The size of this OptionsOrder.  # noqa: E501
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this OptionsOrder.

        Order size. Specify positive number to make a bid, and negative number to ask  # noqa: E501

        :param size: The size of this OptionsOrder.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and size is None:  # noqa: E501
            raise ValueError("Invalid value for `size`, must not be `None`")  # noqa: E501

        self._size = size

    @property
    def iceberg(self):
        """Gets the iceberg of this OptionsOrder.  # noqa: E501

        Display size for iceberg order. 0 for non-iceberg. Note that you will have to pay the taker fee for the hidden size  # noqa: E501

        :return: The iceberg of this OptionsOrder.  # noqa: E501
        :rtype: int
        """
        return self._iceberg

    @iceberg.setter
    def iceberg(self, iceberg):
        """Sets the iceberg of this OptionsOrder.

        Display size for iceberg order. 0 for non-iceberg. Note that you will have to pay the taker fee for the hidden size  # noqa: E501

        :param iceberg: The iceberg of this OptionsOrder.  # noqa: E501
        :type: int
        """

        self._iceberg = iceberg

    @property
    def price(self):
        """Gets the price of this OptionsOrder.  # noqa: E501

        Order price. 0 for market order with `tif` set as `ioc`  # noqa: E501

        :return: The price of this OptionsOrder.  # noqa: E501
        :rtype: str
        """
        return self._price

    @price.setter
    def price(self, price):
        """Sets the price of this OptionsOrder.

        Order price. 0 for market order with `tif` set as `ioc`  # noqa: E501

        :param price: The price of this OptionsOrder.  # noqa: E501
        :type: str
        """

        self._price = price

    @property
    def close(self):
        """Gets the close of this OptionsOrder.  # noqa: E501

        Set as `true` to close the position, with `size` set to 0  # noqa: E501

        :return: The close of this OptionsOrder.  # noqa: E501
        :rtype: bool
        """
        return self._close

    @close.setter
    def close(self, close):
        """Sets the close of this OptionsOrder.

        Set as `true` to close the position, with `size` set to 0  # noqa: E501

        :param close: The close of this OptionsOrder.  # noqa: E501
        :type: bool
        """

        self._close = close

    @property
    def is_close(self):
        """Gets the is_close of this OptionsOrder.  # noqa: E501

        Is the order to close position  # noqa: E501

        :return: The is_close of this OptionsOrder.  # noqa: E501
        :rtype: bool
        """
        return self._is_close

    @is_close.setter
    def is_close(self, is_close):
        """Sets the is_close of this OptionsOrder.

        Is the order to close position  # noqa: E501

        :param is_close: The is_close of this OptionsOrder.  # noqa: E501
        :type: bool
        """

        self._is_close = is_close

    @property
    def reduce_only(self):
        """Gets the reduce_only of this OptionsOrder.  # noqa: E501

        Set as `true` to be reduce-only order  # noqa: E501

        :return: The reduce_only of this OptionsOrder.  # noqa: E501
        :rtype: bool
        """
        return self._reduce_only

    @reduce_only.setter
    def reduce_only(self, reduce_only):
        """Sets the reduce_only of this OptionsOrder.

        Set as `true` to be reduce-only order  # noqa: E501

        :param reduce_only: The reduce_only of this OptionsOrder.  # noqa: E501
        :type: bool
        """

        self._reduce_only = reduce_only

    @property
    def is_reduce_only(self):
        """Gets the is_reduce_only of this OptionsOrder.  # noqa: E501

        Is the order reduce-only  # noqa: E501

        :return: The is_reduce_only of this OptionsOrder.  # noqa: E501
        :rtype: bool
        """
        return self._is_reduce_only

    @is_reduce_only.setter
    def is_reduce_only(self, is_reduce_only):
        """Sets the is_reduce_only of this OptionsOrder.

        Is the order reduce-only  # noqa: E501

        :param is_reduce_only: The is_reduce_only of this OptionsOrder.  # noqa: E501
        :type: bool
        """

        self._is_reduce_only = is_reduce_only

    @property
    def is_liq(self):
        """Gets the is_liq of this OptionsOrder.  # noqa: E501

        Is the order for liquidation  # noqa: E501

        :return: The is_liq of this OptionsOrder.  # noqa: E501
        :rtype: bool
        """
        return self._is_liq

    @is_liq.setter
    def is_liq(self, is_liq):
        """Sets the is_liq of this OptionsOrder.

        Is the order for liquidation  # noqa: E501

        :param is_liq: The is_liq of this OptionsOrder.  # noqa: E501
        :type: bool
        """

        self._is_liq = is_liq

    @property
    def tif(self):
        """Gets the tif of this OptionsOrder.  # noqa: E501

        Time in force  - gtc: GoodTillCancelled - ioc: ImmediateOrCancelled, taker only - poc: PendingOrCancelled, reduce-only  # noqa: E501

        :return: The tif of this OptionsOrder.  # noqa: E501
        :rtype: str
        """
        return self._tif

    @tif.setter
    def tif(self, tif):
        """Sets the tif of this OptionsOrder.

        Time in force  - gtc: GoodTillCancelled - ioc: ImmediateOrCancelled, taker only - poc: PendingOrCancelled, reduce-only  # noqa: E501

        :param tif: The tif of this OptionsOrder.  # noqa: E501
        :type: str
        """
        allowed_values = ["gtc", "ioc", "poc"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and tif not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `tif` ({0}), must be one of {1}".format(tif, allowed_values)  # noqa: E501
            )

        self._tif = tif

    @property
    def left(self):
        """Gets the left of this OptionsOrder.  # noqa: E501

        Size left to be traded  # noqa: E501

        :return: The left of this OptionsOrder.  # noqa: E501
        :rtype: int
        """
        return self._left

    @left.setter
    def left(self, left):
        """Sets the left of this OptionsOrder.

        Size left to be traded  # noqa: E501

        :param left: The left of this OptionsOrder.  # noqa: E501
        :type: int
        """

        self._left = left

    @property
    def fill_price(self):
        """Gets the fill_price of this OptionsOrder.  # noqa: E501

        Fill price of the order  # noqa: E501

        :return: The fill_price of this OptionsOrder.  # noqa: E501
        :rtype: str
        """
        return self._fill_price

    @fill_price.setter
    def fill_price(self, fill_price):
        """Sets the fill_price of this OptionsOrder.

        Fill price of the order  # noqa: E501

        :param fill_price: The fill_price of this OptionsOrder.  # noqa: E501
        :type: str
        """

        self._fill_price = fill_price

    @property
    def text(self):
        """Gets the text of this OptionsOrder.  # noqa: E501

        User defined information. If not empty, must follow the rules below:  1. prefixed with `t-` 2. no longer than 28 bytes without `t-` prefix 3. can only include 0-9, A-Z, a-z, underscore(_), hyphen(-) or dot(.) Besides user defined information, reserved contents are listed below, denoting how the order is created:  - web: from web - api: from API - app: from mobile phones - auto_deleveraging: from ADL - liquidation: from liquidation - insurance: from insurance   # noqa: E501

        :return: The text of this OptionsOrder.  # noqa: E501
        :rtype: str
        """
        return self._text

    @text.setter
    def text(self, text):
        """Sets the text of this OptionsOrder.

        User defined information. If not empty, must follow the rules below:  1. prefixed with `t-` 2. no longer than 28 bytes without `t-` prefix 3. can only include 0-9, A-Z, a-z, underscore(_), hyphen(-) or dot(.) Besides user defined information, reserved contents are listed below, denoting how the order is created:  - web: from web - api: from API - app: from mobile phones - auto_deleveraging: from ADL - liquidation: from liquidation - insurance: from insurance   # noqa: E501

        :param text: The text of this OptionsOrder.  # noqa: E501
        :type: str
        """

        self._text = text

    @property
    def tkfr(self):
        """Gets the tkfr of this OptionsOrder.  # noqa: E501

        Taker fee  # noqa: E501

        :return: The tkfr of this OptionsOrder.  # noqa: E501
        :rtype: str
        """
        return self._tkfr

    @tkfr.setter
    def tkfr(self, tkfr):
        """Sets the tkfr of this OptionsOrder.

        Taker fee  # noqa: E501

        :param tkfr: The tkfr of this OptionsOrder.  # noqa: E501
        :type: str
        """

        self._tkfr = tkfr

    @property
    def mkfr(self):
        """Gets the mkfr of this OptionsOrder.  # noqa: E501

        Maker fee  # noqa: E501

        :return: The mkfr of this OptionsOrder.  # noqa: E501
        :rtype: str
        """
        return self._mkfr

    @mkfr.setter
    def mkfr(self, mkfr):
        """Sets the mkfr of this OptionsOrder.

        Maker fee  # noqa: E501

        :param mkfr: The mkfr of this OptionsOrder.  # noqa: E501
        :type: str
        """

        self._mkfr = mkfr

    @property
    def refu(self):
        """Gets the refu of this OptionsOrder.  # noqa: E501

        Reference user ID  # noqa: E501

        :return: The refu of this OptionsOrder.  # noqa: E501
        :rtype: int
        """
        return self._refu

    @refu.setter
    def refu(self, refu):
        """Sets the refu of this OptionsOrder.

        Reference user ID  # noqa: E501

        :param refu: The refu of this OptionsOrder.  # noqa: E501
        :type: int
        """

        self._refu = refu

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict()) if hasattr(item[1], "to_dict") else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OptionsOrder):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OptionsOrder):
            return True

        return self.to_dict() != other.to_dict()
